@@ -1,7 +1,7 @@
 package Mail::DKIM::Policy;
 use strict;
 use warnings;
-our $VERSION = '1.20240124'; # VERSION
+our $VERSION = '1.20240619'; # VERSION
 # ABSTRACT: abstract base class for originator "signing" policies
 
 # Copyright 2005-2007 Messiah College.
@@ -44,7 +44,7 @@ sub fetch_async {
             next unless $rr->type eq 'TXT';
 
             # join with no intervening spaces, RFC 5617
-            if ( Net::DNS->VERSION >= 0.69 ) {
+            if ( $rr->can('txtdata') ) {
 
                 # must call txtdata() in a list context
                 $strn = join '', $rr->txtdata;
@@ -162,7 +162,7 @@ Mail::DKIM::Policy - abstract base class for originator "signing" policies
 
 =head1 VERSION
 
-version 1.20240124
+version 1.20240619
 
 =head1 SYNOPSIS
 
